Class: Aws::CodeStarconnections::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::CodeStarconnections::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-codestarconnections/client.rb,
sig/client.rbs
Overview
An API client for CodeStarconnections. To construct a client, you need to configure a :region and :credentials.
client = Aws::CodeStarconnections::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateConnectionResponseSuccess, _CreateHostResponseSuccess, _CreateRepositoryLinkResponseSuccess, _CreateSyncConfigurationResponseSuccess, _DeleteConnectionResponseSuccess, _DeleteHostResponseSuccess, _DeleteRepositoryLinkResponseSuccess, _DeleteSyncConfigurationResponseSuccess, _GetConnectionResponseSuccess, _GetHostResponseSuccess, _GetRepositoryLinkResponseSuccess, _GetRepositorySyncStatusResponseSuccess, _GetResourceSyncStatusResponseSuccess, _GetSyncBlockerSummaryResponseSuccess, _GetSyncConfigurationResponseSuccess, _ListConnectionsResponseSuccess, _ListHostsResponseSuccess, _ListRepositoryLinksResponseSuccess, _ListRepositorySyncDefinitionsResponseSuccess, _ListSyncConfigurationsResponseSuccess, _ListTagsForResourceResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateHostResponseSuccess, _UpdateRepositoryLinkResponseSuccess, _UpdateSyncBlockerResponseSuccess, _UpdateSyncConfigurationResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_connection(params = {}) ⇒ Types::CreateConnectionOutput
Creates a connection that can then be given to other Amazon Web Services services like CodePipeline so that it can access third-party code repositories.
-
#create_host(params = {}) ⇒ Types::CreateHostOutput
Creates a resource that represents the infrastructure where a third-party provider is installed.
-
#create_repository_link(params = {}) ⇒ Types::CreateRepositoryLinkOutput
Creates a link to a specified external Git repository.
-
#create_sync_configuration(params = {}) ⇒ Types::CreateSyncConfigurationOutput
Creates a sync configuration which allows Amazon Web Services to sync content from a Git repository to update a specified Amazon Web Services resource.
-
#delete_connection(params = {}) ⇒ Struct
The connection to be deleted.
-
#delete_host(params = {}) ⇒ Struct
The host to be deleted.
-
#delete_repository_link(params = {}) ⇒ Struct
Deletes the association between your connection and a specified external Git repository.
-
#delete_sync_configuration(params = {}) ⇒ Struct
Deletes the sync configuration for a specified repository and connection.
-
#get_connection(params = {}) ⇒ Types::GetConnectionOutput
Returns the connection ARN and details such as status, owner, and provider type.
-
#get_host(params = {}) ⇒ Types::GetHostOutput
Returns the host ARN and details such as status, provider type, endpoint, and, if applicable, the VPC configuration.
-
#get_repository_link(params = {}) ⇒ Types::GetRepositoryLinkOutput
Returns details about a repository link.
-
#get_repository_sync_status(params = {}) ⇒ Types::GetRepositorySyncStatusOutput
Returns details about the sync status for a repository.
-
#get_resource_sync_status(params = {}) ⇒ Types::GetResourceSyncStatusOutput
Returns the status of the sync with the Git repository for a specific Amazon Web Services resource.
-
#get_sync_blocker_summary(params = {}) ⇒ Types::GetSyncBlockerSummaryOutput
Returns a list of the most recent sync blockers.
-
#get_sync_configuration(params = {}) ⇒ Types::GetSyncConfigurationOutput
Returns details about a sync configuration, including the sync type and resource name.
-
#list_connections(params = {}) ⇒ Types::ListConnectionsOutput
Lists the connections associated with your account.
-
#list_hosts(params = {}) ⇒ Types::ListHostsOutput
Lists the hosts associated with your account.
-
#list_repository_links(params = {}) ⇒ Types::ListRepositoryLinksOutput
Lists the repository links created for connections in your account.
-
#list_repository_sync_definitions(params = {}) ⇒ Types::ListRepositorySyncDefinitionsOutput
Lists the repository sync definitions for repository links in your account.
-
#list_sync_configurations(params = {}) ⇒ Types::ListSyncConfigurationsOutput
Returns a list of sync configurations for a specified repository.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Gets the set of key-value pairs (metadata) that are used to manage the resource.
-
#tag_resource(params = {}) ⇒ Struct
Adds to or modifies the tags of the given resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from an Amazon Web Services resource.
-
#update_host(params = {}) ⇒ Struct
Updates a specified host with the provided configurations.
-
#update_repository_link(params = {}) ⇒ Types::UpdateRepositoryLinkOutput
Updates the association between your connection and a specified external Git repository.
-
#update_sync_blocker(params = {}) ⇒ Types::UpdateSyncBlockerOutput
Allows you to update the status of a sync blocker, resolving the blocker and allowing syncing to continue.
-
#update_sync_configuration(params = {}) ⇒ Types::UpdateSyncConfigurationOutput
Updates the sync configuration for your connection and a specified external Git repository.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-codestarconnections/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1766 1767 1768 |
# File 'lib/aws-sdk-codestarconnections/client.rb', line 1766 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1769 1770 1771 |
# File 'lib/aws-sdk-codestarconnections/client.rb', line 1769 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 |
# File 'lib/aws-sdk-codestarconnections/client.rb', line 1739 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::CodeStarconnections') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-codestarconnections' context[:gem_version] = '1.77.0' Seahorse::Client::Request.new(handlers, context) end |
#create_connection(params = {}) ⇒ Types::CreateConnectionOutput
Creates a connection that can then be given to other Amazon Web Services services like CodePipeline so that it can access third-party code repositories. The connection is in pending status until the third-party connection handshake is completed from the console.
88 |
# File 'sig/client.rbs', line 88
def create_connection: (
|
#create_host(params = {}) ⇒ Types::CreateHostOutput
Creates a resource that represents the infrastructure where a third-party provider is installed. The host is used when you create connections to an installed third-party provider type, such as GitHub Enterprise Server. You create one host for all connections to that provider.
PENDING status by
default. You can make its status AVAILABLE by setting up the host
in the console.
107 |
# File 'sig/client.rbs', line 107
def create_host: (
|
#create_repository_link(params = {}) ⇒ Types::CreateRepositoryLinkOutput
Creates a link to a specified external Git repository. A repository link allows Git sync to monitor and sync changes to files in a specified Git repository.
131 |
# File 'sig/client.rbs', line 131
def create_repository_link: (
|
#create_sync_configuration(params = {}) ⇒ Types::CreateSyncConfigurationOutput
Creates a sync configuration which allows Amazon Web Services to sync content from a Git repository to update a specified Amazon Web Services resource. Parameters for the sync configuration are determined by the sync type.
150 |
# File 'sig/client.rbs', line 150
def create_sync_configuration: (
|
#delete_connection(params = {}) ⇒ Struct
The connection to be deleted.
166 |
# File 'sig/client.rbs', line 166
def delete_connection: (
|
#delete_host(params = {}) ⇒ Struct
The host to be deleted. Before you delete a host, all connections associated to the host must be deleted.
175 |
# File 'sig/client.rbs', line 175
def delete_host: (
|
#delete_repository_link(params = {}) ⇒ Struct
Deletes the association between your connection and a specified external Git repository.
184 |
# File 'sig/client.rbs', line 184
def delete_repository_link: (
|
#delete_sync_configuration(params = {}) ⇒ Struct
Deletes the sync configuration for a specified repository and connection.
193 |
# File 'sig/client.rbs', line 193
def delete_sync_configuration: (
|
#get_connection(params = {}) ⇒ Types::GetConnectionOutput
Returns the connection ARN and details such as status, owner, and provider type.
204 |
# File 'sig/client.rbs', line 204
def get_connection: (
|
#get_host(params = {}) ⇒ Types::GetHostOutput
Returns the host ARN and details such as status, provider type, endpoint, and, if applicable, the VPC configuration.
218 |
# File 'sig/client.rbs', line 218
def get_host: (
|
#get_repository_link(params = {}) ⇒ Types::GetRepositoryLinkOutput
Returns details about a repository link. A repository link allows Git sync to monitor and sync changes from files in a specified Git repository.
228 |
# File 'sig/client.rbs', line 228
def get_repository_link: (
|
#get_repository_sync_status(params = {}) ⇒ Types::GetRepositorySyncStatusOutput
Returns details about the sync status for a repository. A repository sync uses Git sync to push and pull changes from your remote repository.
238 |
# File 'sig/client.rbs', line 238
def get_repository_sync_status: (
|
#get_resource_sync_status(params = {}) ⇒ Types::GetResourceSyncStatusOutput
Returns the status of the sync with the Git repository for a specific Amazon Web Services resource.
252 |
# File 'sig/client.rbs', line 252
def get_resource_sync_status: (
|
#get_sync_blocker_summary(params = {}) ⇒ Types::GetSyncBlockerSummaryOutput
Returns a list of the most recent sync blockers.
263 |
# File 'sig/client.rbs', line 263
def get_sync_blocker_summary: (
|
#get_sync_configuration(params = {}) ⇒ Types::GetSyncConfigurationOutput
Returns details about a sync configuration, including the sync type and resource name. A sync configuration allows the configuration to sync (push and pull) changes from the remote repository for a specified branch in a Git repository.
274 |
# File 'sig/client.rbs', line 274
def get_sync_configuration: (
|
#list_connections(params = {}) ⇒ Types::ListConnectionsOutput
Lists the connections associated with your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
286 |
# File 'sig/client.rbs', line 286
def list_connections: (
|
#list_hosts(params = {}) ⇒ Types::ListHostsOutput
Lists the hosts associated with your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
300 |
# File 'sig/client.rbs', line 300
def list_hosts: (
|
#list_repository_links(params = {}) ⇒ Types::ListRepositoryLinksOutput
Lists the repository links created for connections in your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
312 |
# File 'sig/client.rbs', line 312
def list_repository_links: (
|
#list_repository_sync_definitions(params = {}) ⇒ Types::ListRepositorySyncDefinitionsOutput
Lists the repository sync definitions for repository links in your account.
324 |
# File 'sig/client.rbs', line 324
def list_repository_sync_definitions: (
|
#list_sync_configurations(params = {}) ⇒ Types::ListSyncConfigurationsOutput
Returns a list of sync configurations for a specified repository.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
336 |
# File 'sig/client.rbs', line 336
def list_sync_configurations: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Gets the set of key-value pairs (metadata) that are used to manage the resource.
349 |
# File 'sig/client.rbs', line 349
def list_tags_for_resource: (
|
#tag_resource(params = {}) ⇒ Struct
Adds to or modifies the tags of the given resource. Tags are metadata that can be used to manage a resource.
358 |
# File 'sig/client.rbs', line 358
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from an Amazon Web Services resource.
373 |
# File 'sig/client.rbs', line 373
def untag_resource: (
|
#update_host(params = {}) ⇒ Struct
Updates a specified host with the provided configurations.
383 |
# File 'sig/client.rbs', line 383
def update_host: (
|
#update_repository_link(params = {}) ⇒ Types::UpdateRepositoryLinkOutput
Updates the association between your connection and a specified external Git repository. A repository link allows Git sync to monitor and sync changes to files in a specified Git repository.
400 |
# File 'sig/client.rbs', line 400
def update_repository_link: (
|
#update_sync_blocker(params = {}) ⇒ Types::UpdateSyncBlockerOutput
Allows you to update the status of a sync blocker, resolving the blocker and allowing syncing to continue.
414 |
# File 'sig/client.rbs', line 414
def update_sync_blocker: (
|
#update_sync_configuration(params = {}) ⇒ Types::UpdateSyncConfigurationOutput
Updates the sync configuration for your connection and a specified external Git repository.
427 |
# File 'sig/client.rbs', line 427
def update_sync_configuration: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1759 1760 1761 |
# File 'lib/aws-sdk-codestarconnections/client.rb', line 1759 def waiter_names [] end |