Class: Aws::CodeStarconnections::Types::CreateRepositoryLinkInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-codestarconnections/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#connection_arn ⇒ String

The Amazon Resource Name (ARN) of the connection to be associated with the repository link.

Returns:

  • (String)


256
257
258
259
260
261
262
263
264
# File 'lib/aws-sdk-codestarconnections/types.rb', line 256

class CreateRepositoryLinkInput < Struct.new(
  :connection_arn,
  :owner_id,
  :repository_name,
  :encryption_key_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_key_arn ⇒ String

The Amazon Resource Name (ARN) encryption key for the repository to be associated with the repository link.

Returns:

  • (String)


256
257
258
259
260
261
262
263
264
# File 'lib/aws-sdk-codestarconnections/types.rb', line 256

class CreateRepositoryLinkInput < Struct.new(
  :connection_arn,
  :owner_id,
  :repository_name,
  :encryption_key_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#owner_id ⇒ String

The owner ID for the repository associated with a specific sync configuration, such as the owner ID in GitHub.

Returns:

  • (String)


256
257
258
259
260
261
262
263
264
# File 'lib/aws-sdk-codestarconnections/types.rb', line 256

class CreateRepositoryLinkInput < Struct.new(
  :connection_arn,
  :owner_id,
  :repository_name,
  :encryption_key_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#repository_name ⇒ String

The name of the repository to be associated with the repository link.

Returns:

  • (String)


256
257
258
259
260
261
262
263
264
# File 'lib/aws-sdk-codestarconnections/types.rb', line 256

class CreateRepositoryLinkInput < Struct.new(
  :connection_arn,
  :owner_id,
  :repository_name,
  :encryption_key_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Array<Types::Tag>

The tags for the repository to be associated with the repository link.

Returns:



256
257
258
259
260
261
262
263
264
# File 'lib/aws-sdk-codestarconnections/types.rb', line 256

class CreateRepositoryLinkInput < Struct.new(
  :connection_arn,
  :owner_id,
  :repository_name,
  :encryption_key_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end